nsfw\_dl
--------

.. image:: https://img.shields.io/pypi/v/nsfw-dl.svg
   :target: https://pypi.python.org/pypi/nsfw-dl/
.. image:: https://img.shields.io/pypi/pyversions/nsfw-dl.svg
   :target: https://pypi.python.org/pypi/nsfw-dl/
.. image:: https://travis-ci.org/IzunaDevs/nsfw_dl.svg?branch=master
   :target: https://travis-ci.org/IzunaDevs/nsfw_dl

This is an discord library that works with aiohttp and async.

It uses Python 3.5+ syntax.

Documentation
-------------

There is no documentation as of yet for usage of ``nsfw_dl``.

Known Issues
------------

It is known that ``drunkenpumken`` does not have an working search (I
need to figure out how to send an tag to the api if they have one to get
the same result as most of the other search classes).

Also I could not figure out an search for ``nhentai``, ``tsumino``, and
``hbrowse``.

If you know how to do it for search terms / tags that would help finish
this library.
